@@ -32,13 +32,14 @@ pub fn run(arg: PathBuf) {
 
     let mut state = State::new();
 
-    let time_start = if column >= 48 { 32 } else { column - 16 };
+    let time_start = if column >= 48 { 31 } else { column - 17 };
     let name_max: usize = if column >= 48 {
         29
     } else {
         (time_start - 2).into()
     };
     state.layout = Layout {
+        terminal_row: row,
         name_max_len: name_max,
         time_start_pos: time_start,
     };
@@ -118,7 +119,6 @@ pub fn run(arg: PathBuf) {
                             let input = stdin.next();
                             if let Some(Ok(key)) = input {
                                 match key {
-                                    //Input char(case-sensitive)
                                     Key::Char('g') => {
                                         print!("{}", cursor::Hide);
                                         nums.reset();
@@ -229,22 +229,64 @@ pub fn run(arg: PathBuf) {
                 //Go to parent directory if exists
                 Key::Char('h') | Key::Left => match state.current_dir.parent() {
                     Some(parent_p) => {
+                        let pre = state.current_dir.clone();
+                        let pre = pre.file_name().unwrap().to_str();
+
                         state.current_dir = parent_p.to_path_buf();
                         std::env::set_current_dir(&state.current_dir)
                             .unwrap_or_else(|e| print_warning(e, y));
                         state.update_list();
-                        clear_and_show(&state.current_dir);
-                        state.list_up(0);
 
                         match memo_v.pop() {
                             Some(memo) => {
                                 nums = memo.num;
+                                clear_and_show(&state.current_dir);
+                                state.list_up(nums.skip);
                                 print!("{}>{}", cursor::Goto(1, memo.cursor_pos), cursor::Left(1));
                             }
-                            None => {
-                                nums.reset();
-                                print!("{}>{}", cursor::Goto(1, STARTING_POINT), cursor::Left(1));
-                            }
+                            None => match pre {
+                                Some(name) => {
+                                    let mut new_pos = 0;
+                                    for (i, item) in state.list.iter().enumerate() {
+                                        if item.file_name == name {
+                                            new_pos = i;
+                                        }
+                                    }
+                                    nums.index = new_pos;
+
+                                    if nums.index
+                                        > (state.layout.terminal_row - (STARTING_POINT + 1)).into()
+                                    {
+                                        nums.skip = (nums.index - 3) as u16;
+                                        clear_and_show(&state.current_dir);
+                                        state.list_up(nums.skip);
+                                        print!(
+                                            "{}>{}",
+                                            cursor::Goto(1, STARTING_POINT + 3),
+                                            cursor::Left(1)
+                                        );
+                                    } else {
+                                        nums.skip = 0;
+                                        clear_and_show(&state.current_dir);
+                                        state.list_up(0);
+                                        print!(
+                                            "{}>{}",
+                                            cursor::Goto(1, (nums.index + 3) as u16),
+                                            cursor::Left(1)
+                                        );
+                                    }
+                                }
+                                None => {
+                                    nums.reset();
+                                    clear_and_show(&state.current_dir);
+                                    state.list_up(0);
+                                    print!(
+                                        "{}>{}",
+                                        cursor::Goto(1, STARTING_POINT),
+                                        cursor::Left(1)
+                                    );
+                                }
+                            },
                         }
                     }
                     None => {
@@ -312,7 +354,6 @@ pub fn run(arg: PathBuf) {
                                     }
                                 }
 
-                                //Go down. If lists exceed max-row, lists "scrolls" before the bottom of the list
                                 Key::Char('k') | Key::Up => {
                                     if y == STARTING_POINT {
                                         continue;
@@ -356,7 +397,6 @@ pub fn run(arg: PathBuf) {
                                     }
                                 }
 
-                                //Go to top
                                 Key::Char('g') => {
                                     if nums.index == 0 {
                                         continue;
@@ -370,7 +410,6 @@ pub fn run(arg: PathBuf) {
                                             let input = stdin.next();
                                             if let Some(Ok(key)) = input {
                                                 match key {
-                                                    //Input char(case-sensitive)
                                                     Key::Char('g') => {
                                                         print!("{}", cursor::Hide);
                                                         nums.reset();
@@ -617,7 +656,6 @@ pub fn run(arg: PathBuf) {
                         let input = stdin.next();
                         if let Some(Ok(key)) = input {
                             match key {
-                                //Input char(case-sensitive)
                                 Key::Char('y') => {
                                     state.yank_item(nums.index, false);
                                     print!("{}", clear::CurrentLine);
@@ -718,7 +756,6 @@ pub fn run(arg: PathBuf) {
                                     break;
                                 }
 
-                                //Exit rename mode and return to original lists
                                 Key::Esc => {
                                     print!("{}", clear::CurrentLine);
                                     print!("{}{}", cursor::Goto(2, 2), DOWN_ARROW);
@@ -749,7 +786,6 @@ pub fn run(arg: PathBuf) {
                                     screen.flush().unwrap();
                                 }
 
-                                //Input char(case-sensitive)
                                 Key::Char(c) => {
                                     let memo_x = x;
                                     rename.insert((x - 4).into(), c);
@@ -868,7 +904,6 @@ pub fn run(arg: PathBuf) {
                                     screen.flush().unwrap();
                                 }
 
-                                //Input char(case-sensitive)
                                 Key::Char(c) => {
                                     let memo_x = x;
                                     keyword.insert((x - 4).into(), c);
@@ -1065,22 +1100,6 @@ pub fn run(arg: PathBuf) {
                                         break 'command;
                                     }
 
-                                    // if c == "cd" {
-                                    //     current_dir =
-                                    //         PathBuf::from(args[0]).canonicalize().unwrap();
-                                    //     state.update_list();
-                                    //     clear_and_show(&state.current_dir);
-                                    //     state.list_up(0);
-                                    //     print!(
-                                    //         "{}{}>{}",
-                                    //         cursor::Hide,
-                                    //         cursor::Goto(1, STARTING_POINT),
-                                    //         cursor::Left(1),
-                                    //     );
-                                    //     nums.reset();
-                                    //     break 'command;
-                                    // }
-
                                     print!("{}", screen::ToAlternateScreen);
                                     if std::env::set_current_dir(&state.current_dir).is_err() {
                                         print!("{}", cursor::Hide,);
@@ -1141,7 +1160,6 @@ pub fn run(arg: PathBuf) {
                                     screen.flush().unwrap();
                                 }
 
-                                //Input char(case-sensitive)
                                 Key::Char(c) => {
                                     command.insert((x - 3).into(), c);
 
@@ -1202,7 +1220,6 @@ pub fn run(arg: PathBuf) {
                                     break 'quit;
                                 }
 
-                                //Input char(case-sensitive)
                                 Key::Char(c) => {
                                     command.push(c);
 
