@@ -74,6 +74,7 @@ pub enum FileType {
 
 #[derive(Clone)]
 pub struct Layout {
+    pub terminal_row: u16,
     pub name_max_len: usize,
     pub time_start_pos: u16,
 }
@@ -95,6 +96,7 @@ impl Default for State {
             commands: to_extension_map(&config.exec),
             sort_by: config.sort_by,
             layout: Layout {
+                terminal_row: 0,
                 name_max_len: 0,
                 time_start_pos: 0,
             },
@@ -144,23 +146,27 @@ impl State {
         //prepare from and to for copy
         let from = &item.file_path;
 
-        let name = &item.file_name;
-        let mut rename = Local::now().timestamp().to_string();
-        rename.push('_');
-        rename.push_str(name);
+        if item.file_type == FileType::Symlink && !from.exists() {
+            let _ = Command::new("rm").arg(from).status();
+            Ok(())
+        } else {
+            let name = &item.file_name;
+            let mut rename = Local::now().timestamp().to_string();
+            rename.push('_');
+            rename.push_str(name);
 
-        let to = self.trash_dir.join(&rename);
+            let to = self.trash_dir.join(&rename);
 
-        //copy
-        std::fs::copy(from, &to)?;
+            //copy
+            std::fs::copy(from, &to)?;
 
-        //copy original information to item_buf
-        self.to_registered_mut(&item, to, rename);
+            self.to_registered_mut(&item, to, rename);
 
-        //remove original
-        std::fs::remove_file(from)?;
+            //remove original
+            std::fs::remove_file(from)?;
 
-        Ok(())
+            Ok(())
+        }
     }
 
     pub fn remove_and_yank_dir(&mut self, item: ItemInfo) -> std::io::Result<()> {
@@ -202,7 +208,6 @@ impl State {
             }
         }
 
-        //copy original information to item_buf
         self.to_registered_mut(&item, trash_path, trash_name);
 
         //remove original
@@ -501,10 +506,10 @@ impl State {
     }
 
     pub fn list_up(&self, skip_number: u16) {
-        let (_, row) = termion::terminal_size().unwrap();
+        let row = self.layout.terminal_row;
         let len = self.list.len();
 
-        //if lists exceed max-row
+        //if list exceeds max-row
         if len > (row - STARTING_POINT) as usize - 1 {
             let mut row_count = 0;
             for (i, _) in self.list.iter().enumerate() {
@@ -523,7 +528,7 @@ impl State {
                         cursor::Left(2),
                         color::Bg(color::LightWhite),
                         color::Fg(color::Black),
-                        skip_number,
+                        skip_number + 1,
                         row - STARTING_POINT + skip_number,
                         len,
                         color::Bg(color::Reset),
@@ -554,26 +559,22 @@ impl State {
     }
 
     pub fn select_from_top(&mut self, start_pos: usize) {
-        let mut i = 0;
-        for mut item in self.list.iter_mut() {
+        for (i, item) in self.list.iter_mut().enumerate() {
             if i <= start_pos {
                 item.selected = true;
             } else {
                 item.selected = false;
             }
-            i += 1;
         }
     }
 
     pub fn select_to_bottom(&mut self, start_pos: usize) {
-        let mut i = 0;
-        for mut item in self.list.iter_mut() {
+        for (i, item) in self.list.iter_mut().enumerate() {
             if i < start_pos {
                 item.selected = false;
             } else {
                 item.selected = true;
             }
-            i += 1;
         }
     }
 }
